@@ -1,14 +1,13 @@
-import json
-
-# from msilib.schema import Registry
 from os import getenv
 from pathlib import Path
 
 import connexion
 from flask import Flask, render_template, send_from_directory
+from pkg_resources import resource_filename
 from prometheus_client import CollectorRegistry, make_wsgi_app
 from redis import Redis
 from werkzeug.middleware.dispatcher import DispatcherMiddleware
+from yaml import safe_load
 
 import asu.common
 from asu import __version__
@@ -37,7 +36,6 @@ def create_app(test_config: dict = None) -> Flask:
         TESTING=False,
         DEBUG=False,
         UPSTREAM_URL="https://downloads.openwrt.org",
-        BRANCHES={},
         ALLOW_DEFAULTS=False,
         ASYNC_QUEUE=True,
     )
@@ -60,6 +58,13 @@ def create_app(test_config: dict = None) -> Flask:
             app.config[option] = Path(value)
             app.config[option].mkdir(parents=True, exist_ok=True)
 
+    if not "BRANCHES" in app.config:
+        if "BRANCHES_FILE" not in app.config:
+            app.config["BRANCHES_FILE"] = resource_filename(__name__, "branches.yml")
+
+        with open(app.config["BRANCHES_FILE"], "r") as branches:
+            app.config["BRANCHES"] = safe_load(branches)["branches"]
+
     app.wsgi_app = DispatcherMiddleware(
         app.wsgi_app, {"/metrics": make_wsgi_app(app.config["REGISTRY"])}
     )
@@ -95,40 +100,6 @@ def create_app(test_config: dict = None) -> Flask:
             filter(lambda b: b.get("enabled"), app.config["BRANCHES"].values()),
         )
     )
-    latest = list(
-        map(
-            lambda b: b["versions"][0],
-            filter(
-                lambda b: b.get("enabled"),
-                app.config["BRANCHES"].values(),
-            ),
-        )
-    )
-
-    app.config["OVERVIEW"] = {
-        "latest": latest,
-        "branches": branches,
-        "server": {
-            "version": __version__,
-            "contact": "mail@aparcar.org",
-            "allow_defaults": app.config["ALLOW_DEFAULTS"],
-        },
-    }
-
-    # legacy
-    (app.config["JSON_PATH"] / "branches.json").write_text(
-        json.dumps(list(branches.values()))
-    )
-
-    # tdb
-    (app.config["JSON_PATH"] / "latest.json").write_text(json.dumps({"latest": latest}))
-
-    (app.config["JSON_PATH"] / "overview.json").write_text(
-        json.dumps(
-            app.config["OVERVIEW"],
-            indent=2,
-        )
-    )
 
     @app.route("/")
     def overview():
@@ -136,7 +107,6 @@ def create_app(test_config: dict = None) -> Flask:
             "overview.html",
             branches=branches,
             defaults=app.config["ALLOW_DEFAULTS"],
-            latest=latest,
             version=__version__,
         )
 
